@@ -103,7 +103,7 @@ class MerginClient:
                 system_version = "Linux"
         elif platform.system() == "Windows":
             system_version = platform.win32_ver()[0]
-        elif platform.system() == "Mac":
+        elif platform.system() in ["Mac", "Darwin"]:
             system_version = platform.mac_ver()[0]
         return f"{self.client_version} ({platform.system()}/{system_version})"
 
@@ -246,7 +246,7 @@ class MerginClient:
             return None  # not authenticated
         return self._user_info["username"]
 
-    def create_project(self, project_name, is_public=False):
+    def create_project(self, project_name, is_public=False, namespace=None):
         """
         Create new project repository in user namespace on Mergin server.
         Optionally initialized from given local directory.
@@ -255,7 +255,10 @@ class MerginClient:
         :type project_name: String
 
         :param is_public: Flag for public/private project, defaults to False
-        :type directory: Boolean
+        :type is_public: Boolean
+
+        :param namespace: Optional namespace for a new project. If empty username is used.
+        :type namespace: String
         """
         if not self._user_info:
             raise Exception("Authentication required")
@@ -264,14 +267,10 @@ class MerginClient:
             "name": project_name,
             "public": is_public
         }
-        namespace = self.username()
+        if namespace is None:
+            namespace = self.username()
         try:
             self.post("/v1/project/%s" % namespace, params, {"Content-Type": "application/json"})
-            data = {
-                "name": "%s/%s" % (namespace, project_name),
-                "version": "v0",
-                "files": []
-            }
         except Exception as e:
             detail = f"Namespace: {namespace}, project name: {project_name}"
             raise ClientError(str(e), detail)
@@ -360,11 +359,9 @@ class MerginClient:
         download_project_finalize(job)
 
     def enough_storage_available(self, data):
-        user_name = self.username()
-        resp = self.get('/v1/user/' + user_name)
-        info = json.load(resp)
+        info = self.user_info()
         free_space = int(info["storage_limit"]) - int(info["disk_usage"])
-        upload_files_sizes =[f["size"] for f in data["updated"] + data["added"]]
+        upload_files_sizes = [f["size"] for f in data["updated"] + data["added"]]
         size_to_upload = sum(upload_files_sizes)
 
         if size_to_upload > free_space:
@@ -372,6 +369,10 @@ class MerginClient:
 
         return True, free_space
 
+    def user_info(self):
+        resp = self.get('/v1/user/' + self.username())
+        return json.load(resp)
+
     def push_project(self, directory):
         """
         Upload local changes to the repository.
@@ -398,6 +399,28 @@ class MerginClient:
         pull_project_wait(job)
         return pull_project_finalize(job)
 
+    def clone_project(self, source_project_path, cloned_project_name, cloned_project_namespace=None):
+        """
+        Clone project on server.
+        :param source_project_path: Project's full name (<namespace>/<name>)
+        :type source_project_path: String
+        :param cloned_project_name: Cloned project's name
+        :type cloned_project_name: String
+        :param cloned_project_namespace: Cloned project's namespace, username is used if not defined
+        :type cloned_project_namespace: String
+
+        """
+        path = "/v1/project/clone/%s" % source_project_path
+        url = urllib.parse.urljoin(self.url, urllib.parse.quote(path))
+        json_headers = {'Content-Type': 'application/json', 'Accept': 'application/json'}
+        data = {
+            'namespace': cloned_project_namespace if cloned_project_namespace else self.username(),
+            'project': cloned_project_name
+        }
+
+        request = urllib.request.Request(url, data=json.dumps(data).encode(), headers=json_headers, method="POST")
+        self._do_request(request)
+
     def delete_project(self, project_path):
         """
         Delete project repository on server.
